---
name: Bug Report
about: Create a bug report to help us improve
labels: bug
---

<!-- Please search existing issues to avoid creating duplicates. -->

### Environment Information

Please run the following code on your computer and share the output with us so that we can better debug your issue:

```python
import geemap
geemap.Report()
```

### Description

Describe what you were trying to get done.
Tell us what happened, what went wrong, and what you expected to happen.

### What I Did

```
Paste the command(s) you ran and the output.
If there was a crash, please include the traceback here.
```
